@@ -2,7 +2,7 @@
 #'
 #' Evaluates whether a design satisfies the equivalence theorem.
 #'
-#' @param best_particle A vector containing the best particle's position (i.e., stress levels and transformed allocated proportion).
+#' @param best_design A matrix containing stress levels and allocated proportion of the design.
 #' @param model_set A matrix of models, including parameters and distribution, that maximize the optimality criteria with the given best particle's position.
 #' @param design_info A list containing design parameters such as factor levels, number of units, and other settings.
 #' @param seed Seed for reproducibility
@@ -18,13 +18,16 @@
 #' design_info <- set_design_info(k_levels=2, j_factor=1, n_unit=300, 
 #'                                censor_time=183, p=0.1, use_cond=0, sigma=0.6)
 #'                                
-#' best_particle <- c(0.682, 1, 0.706)
+#' best_design <- rbind(
+#'   c(0.682, 1), 
+#'   c(0.706, 0.294)
+#' )
 #' 
 #' model_set <- rbind(
 #'   c(0.01, 0.9, 1),
 #'   c(0.01, 0.99, 2))
 #' 
-#' equi <- check_equivalence_theorem (best_particle=best_particle, 
+#' equi <- check_equivalence_theorem (best_design=best_design, 
 #'                                     model_set=model_set, 
 #'                                     design_info=design_info)
 #' 
@@ -39,7 +42,22 @@
 #' @rdname check_equivalence_theorem
 #' @importFrom Rcpp evalCpp cppFunction sourceCpp
 #' @export
-check_equivalence_theorem <- function(best_particle, model_set, design_info, seed = 42) {
+check_equivalence_theorem <- function(best_design, model_set, design_info, seed = 42) {
+  
+  # transform design into particle
+  stopifnot(is.matrix(best_design))
+  j <- nrow(best_design)
+  k <- ncol(best_design)
+  stopifnot(design_info$n_factor == j - 1)
+  stopifnot(design_info$n_support == k)
+  stopifnot(all(best_design[j,] >= 0),
+            all(best_design[j,] <= 1)
+            )
+  stopifnot(sum(best_design[j,]) == 1)
+  
+  transform_prop <- get_transform_prop(best_design[j,])
+  best_particle <- c(t(best_design[1:j-1, 1:k]))
+  best_particle <- c(best_particle, transform_prop) 
   
   # stopifnot(design_info$opt_type == "C")
   design_info$opt_type = "C"
@@ -55,7 +73,6 @@ check_equivalence_theorem <- function(best_particle, model_set, design_info, see
   use_cond = c(design_info$use_cond)
   stopifnot(design_info$n_factor == length(use_cond))
   
-  stopifnot(is.vector(best_particle))
   stopifnot(is.matrix(model_set))
   
   seed = round(seed, digits = 0)
